summaryrefslogtreecommitdiffstats
path: root/klettres
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit96698e12d1d6ba8072e9365334277438c3cf0e4a (patch)
tree81e81a49226aab2570d5fe8464576a6c960f1782 /klettres
parentdcb06497ea70d050554422eec10b0756d926a5c0 (diff)
downloadtdeedu-96698e12d1d6ba8072e9365334277438c3cf0e4a.tar.gz
tdeedu-96698e12d1d6ba8072e9365334277438c3cf0e4a.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'klettres')
-rw-r--r--klettres/klettres/fontsdlg.ui2
-rw-r--r--klettres/klettres/klettres.cpp14
-rw-r--r--klettres/klettres/klettres.h4
-rw-r--r--klettres/klettres/soundfactory.cpp4
-rw-r--r--klettres/klettres/soundfactory.h2
-rw-r--r--klettres/klettres/timerdlg.ui2
6 files changed, 14 insertions, 14 deletions
diff --git a/klettres/klettres/fontsdlg.ui b/klettres/klettres/fontsdlg.ui
index 8e88dc9b..5853adfd 100644
--- a/klettres/klettres/fontsdlg.ui
+++ b/klettres/klettres/fontsdlg.ui
@@ -31,7 +31,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kfontdialog.h</includehint>
</includehints>
diff --git a/klettres/klettres/klettres.cpp b/klettres/klettres/klettres.cpp
index cbd4c165..9839f4bf 100644
--- a/klettres/klettres/klettres.cpp
+++ b/klettres/klettres/klettres.cpp
@@ -167,11 +167,11 @@ TQString Prefs::defaultLanguage()
}
-bool KLettres::loadLayout(TQDomDocument &tqlayoutDocument)
+bool KLettres::loadLayout(TQDomDocument &layoutDocument)
{
- TQFile tqlayoutFile(locate("data", "klettres/"+Prefs::language()+"/sounds.xml"));
+ TQFile layoutFile(locate("data", "klettres/"+Prefs::language()+"/sounds.xml"));
//if xml file is not found, program exits
- if (!tqlayoutFile.exists())
+ if (!layoutFile.exists())
{
kdWarning() << "sounds.xml file not found in $KDEDIR/share/apps/klettres/"+Prefs::language() << endl;
TQString mString=i18n("The file sounds.xml was not found in\n"
@@ -180,15 +180,15 @@ bool KLettres::loadLayout(TQDomDocument &tqlayoutDocument)
KMessageBox::information( this, mString,"KLettres - Error" );
kapp->quit();//exit(1);
}
- if (!tqlayoutFile.open(IO_ReadOnly))
+ if (!layoutFile.open(IO_ReadOnly))
return false;
//Check if document is well-formed
- if (!tqlayoutDocument.setContent(&tqlayoutFile))
+ if (!layoutDocument.setContent(&layoutFile))
{
- tqlayoutFile.close();
+ layoutFile.close();
return false;
}
- tqlayoutFile.close();
+ layoutFile.close();
return true;
}
diff --git a/klettres/klettres/soundfactory.cpp b/klettres/klettres/soundfactory.cpp
index 6a2a0ebf..fdddd5de 100644
--- a/klettres/klettres/soundfactory.cpp
+++ b/klettres/klettres/soundfactory.cpp
@@ -78,7 +78,7 @@ void SoundFactory::loadFailure()
KMessageBox::error(klettres, i18n("Error while loading the sound names."));
}
-bool SoundFactory::loadLanguage(TQDomDocument &tqlayoutDocument, TQString currentLanguage)
+bool SoundFactory::loadLanguage(TQDomDocument &layoutDocument, TQString currentLanguage)
{
TQDomNodeList languagesList,
alphabetList,
@@ -90,7 +90,7 @@ bool SoundFactory::loadLanguage(TQDomDocument &tqlayoutDocument, TQString curren
soundNameElement;
TQDomAttr nameAttribute, fileAttribute;
- languagesList = tqlayoutDocument.elementsByTagName("language");
+ languagesList = layoutDocument.elementsByTagName("language");
TQDomAttr codeAttribute;
//check if the sound files match current language
languageElement = (const TQDomElement &) languagesList.item(0).toElement();
diff --git a/klettres/klettres/soundfactory.h b/klettres/klettres/soundfactory.h
index e6105db7..032ad0ca 100644
--- a/klettres/klettres/soundfactory.h
+++ b/klettres/klettres/soundfactory.h
@@ -65,7 +65,7 @@ public:
* Call that when you read the language from Config and when the language changes
* or when the level changes
*/
- bool loadLanguage(TQDomDocument &tqlayoutDocument, TQString currentLanguage);
+ bool loadLanguage(TQDomDocument &layoutDocument, TQString currentLanguage);
///The language document
TQDomDocument m_layoutsDocument;
diff --git a/klettres/klettres/timerdlg.ui b/klettres/klettres/timerdlg.ui
index afbe9b63..089399a8 100644
--- a/klettres/klettres/timerdlg.ui
+++ b/klettres/klettres/timerdlg.ui
@@ -238,7 +238,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kactivelabel.h</includehint>
</includehints>
diff --git a/klettres/klettres/klettres.h b/klettres/klettres/klettres.h
index cff0d88c..54ec92fb 100644
--- a/klettres/klettres/klettres.h
+++ b/klettres/klettres/klettres.h
@@ -62,10 +62,10 @@ public:
TQStringList m_languageNames;
/**
*Load the xml file
*@param tqlayoutDocument the xml file
*@return bool true if the xml document is found and well formed, false otherwise
*/
- bool loadLayout(TQDomDocument &tqlayoutDocument);
+ bool loadLayout(TQDomDocument &layoutDocument);
///Number corresponding to the selected language: 0 is Czech, 1 is Danish, 2 is English (default), 3 is French, 4 is Dutch, 5 is Slovak
//uint selectedLanguage;
///Action that sets up the Language menu
@@ -62,10 +62,10 @@ public:
/**
*Load the xml file
- *@param tqlayoutDocument the xml file
+ *@param layoutDocument the xml file
*@return bool true if the xml document is found and well formed, false otherwise
*/